%define major           0.8
%define libname         %mklibname brlapi %{major}
%define develname       %mklibname brlapi -d

# "fix" underlinking:
%define _disable_ld_no_undefined 1

%ifarch %arm %mips
%define build_java 0
%else
%define build_java 1
%endif

Name:           brltty
Version:        6.7
Release:        %mkrel 1
Summary:        Braille display driver for Linux/Unix
License:	LGPLv2+
Group:          Accessibility
URL:		https://brltty.app/
Source0:	https://brltty.app/archive/%{name}-%{version}.tar.xz
Source1: brltty.service
# Fedora patch
Patch1: brltty-6.3-loadLibrary.patch
# libspeechd.h moved in latest speech-dispatch (NOT sent upstream)
Patch2: brltty-6.3-libspeechd.patch
BuildRequires:  icu-devel
BuildRequires:  systemd-devel
BuildRequires:  bison
BuildRequires:  festival-devel
BuildRequires:  gpm-devel
BuildRequires:  libbraille-devel
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-findlib
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(setuptools)
BuildRequires:  speech_tools-devel
BuildRequires:  subversion
BuildRequires:  libespeak-devel
BuildRequires:  doxygen
BuildRequires:  python3-docutils

%description
BRLTTY is a background process (daemon) which provides
access to the Linux/Unix console (when in text mode)
for a blind person using a refreshable braille display.
It drives the braille display and provides complete
screen review functionality.
Some speech capability has also been incorporated.

%package -n %{libname}
Summary:    API for brltty
Group:      System/Libraries
License:    LGPLv2+

%description -n %{libname}
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n %{develname}
Group:      Development/C
License:    LGPLv2+
Summary:    Headers, static archive, and documentation for BrlAPI
Provides:   brlapi-devel = %{version}-%{release}
Requires:   %{libname} = %{version}-%{release}

%description -n %{develname}
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically attuned to their needs.

Install this package if you are developing or maintaining an application
which directly accesses a refreshable braille display.

%package -n python3-brlapi
Summary:    Python 3 bindings for BrlAPI
Group:      Development/Python
%{?python_provide:%python_provide python3-brlapi}

%description -n python3-brlapi
This package provides the Python 3 binding for BrlAPI.

%if %{build_java}
%package -n brlapi-java
Group:      Development/Java
Summary:    Java binding for BrlAPI
BuildRequires:  java-devel

%description -n brlapi-java
This package provides the Java binding for BrlAPI.
%endif

%package -n ocaml-brlapi
Summary:    Ocaml bindings for BrlAPI
Group:      Development/OCaml
Obsoletes:  brlapi-ocaml < %{version}-%{release}

%description -n ocaml-brlapi
This package provides the OCaml binding for BrlAPI.

%package -n ocaml-brlapi-devel
Summary:    Development files for ocaml-brlapi
Group:      Development/OCaml
Requires:   ocaml-brlapi = %{version}-%{release}
Requires:   brlapi-devel

%description  -n ocaml-brlapi-devel
The ocaml-brlapi-devel package contains libraries and signature files for
developing applications that use ocaml-brlapi.

%package dracut
Summary:    brltty module for Dracut
Requires:   %{name}%{?_isa} = %{version}-%{release}
Requires:   dracut

%description dracut
This package provides brltty module for Dracut.

%prep
%autosetup -p1

# produce debuginfo for the OCaml interface
sed -i 's/@OCAMLC@/& -g/;s/@OCAMLOPT@/& -g/;s/@OCAMLMKLIB@/& -g/' \
    Bindings/OCaml/Makefile.in

%build
autoconf -v -f
# Add the openjdk include directories to CPPFLAGS
for i in -I/usr/lib/jvm/java/include{,/linux}; do
      java_inc="$java_inc $i"
done
export CPPFLAGS="$java_inc"

export LDFLAGS="%{?build_ldflags}"
export CFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export CXXFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export PYTHON=%{__python3}
%configure  CPPFLAGS="$java_inc" \
                --with-install-root="%{buildroot}" \
                --disable-relocatable-install \
                --disable-tcl-bindings \
                --disable-stripping

# Parallel build seems broken, thus disabling it
make

# documents
pushd Documents
# (tv) broken in 6.4:
#make
popd

%install
install -d -m 755 %{buildroot}%{_libdir}/ocaml/stublibs
# just to avoid an installation error
touch %{buildroot}%{_libdir}/ocaml/ld.conf
make install

# install polkit rules
pushd Authorization/Polkit
make install
popd

install -m644 Documents/%{name}.conf -D %{buildroot}%{_sysconfdir}/%{name}.conf
install -m644 Documents/%{name}.1 -D %{buildroot}%{_mandir}/man1/%{name}.1
rm -f %{buildroot}%{_libdir}/ocaml/ld.conf

%if %{build_java}
# Missing java library
install -d -m 755 %{buildroot}%{_libdir}/java/
cp Bindings/Java/*.so '%{buildroot}%{_libdir}/java/'
# for some reason 64-bit install libbrlapi_java.so in both lib and lib64
# So we'll remove it
%ifarch x86_64 aarch64
rm -rf %{buildroot}%{_prefix}/lib/java
%endif
%endif

# Missing ocaml library
cp Bindings/OCaml/*.a '%{buildroot}%{_libdir}/ocaml/brlapi/'
%ifnarch %mips
cp Bindings/OCaml/*.cmx '%{buildroot}%{_libdir}/ocaml/brlapi/'
%endif

install -Dpm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/brltty.service

directory="doc"
mkdir -p "${directory}"
for file in `find . \( -path "./${directory}" -o -path ./Documents \) -prune -o \( -name 'README*' -o -name '*.patch' -o -name '*.txt' -o -name '*
.html' -o -name '*.sgml' -o \( -path "./Bootdisks/*" -type f -perm +ugo=x \) \) -print`
do
   mkdir -p "${directory}/${file%/*}"
   cp -rp "${file}" "${directory}/${file}"
done

# handle locales
%find_lang %{name}
cp -p %{name}.lang ../

# install dracut module
make install-dracut

%post
%systemd_post brltty.service

%preun
%systemd_preun brltty.service

%postun
%systemd_postun_with_restart brltty.service

%files -f %{name}.lang
%doc README Documents/ChangeLog Documents/TODO
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_unitdir}/brltty.service
%{_bindir}/*
%{_sysconfdir}/%{name}
%{_sysconfdir}/X11/Xsession.d/90xbrlapi
%{_libdir}/%{name}
%{_libexecdir}/*
%{_mandir}/man1/*
%{_datadir}/gdm/greeter/autostart/xbrlapi.desktop
%{_datadir}/polkit-1/actions/org.a11y.brlapi.policy
%{_datadir}/polkit-1/rules.d/org.a11y.brlapi.rules

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_libdir}/*.a
%{_includedir}/brlapi.h
%{_includedir}/brlapi_*.h
%{_includedir}/brltty
%{_libdir}/pkgconfig/brltty.pc
%{_mandir}/man3/*

%if %{build_java}
%files -n brlapi-java
%{_libdir}/java/libbrlapi_java.so
%{_datadir}/java/brlapi.jar
%endif

%files -n python3-brlapi
%{python3_sitearch}/*

%files -n ocaml-brlapi
%dir %{_libdir}/ocaml/brlapi
%{_libdir}/ocaml/brlapi/META
%{_libdir}/ocaml/brlapi/*.cma
%{_libdir}/ocaml/brlapi/*.cmi
%{_libdir}/ocaml/stublibs/*.so*

%files -n ocaml-brlapi-devel
%{_libdir}/ocaml/brlapi/*.a
%ifnarch %mips
%{_libdir}/ocaml/brlapi/*.cmxa
%{_libdir}/ocaml/brlapi/*.cmx
%endif
%{_libdir}/ocaml/brlapi/*.mli

%files dracut
%{_prefix}/lib/dracut/modules.d/99brltty/
%dir %{_sysconfdir}/brltty/Initramfs
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/dracut.conf
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/cmdline


%changelog
* Wed Nov 27 2024 daviddavid <daviddavid> 6.7-1.mga10
+ Revision: 2119479
- new version: 6.7

* Tue Dec 19 2023 wally <wally> 6.6-3.mga10
+ Revision: 2019285
- rebuild for py3.12

* Tue Sep 26 2023 tv <tv> 6.6-2.mga10
+ Revision: 1991120
- Rebuild for icu-73

* Sat Sep 16 2023 tv <tv> 6.6-1.mga10
+ Revision: 1987121
- 6.6

* Sat Jan 07 2023 squidf <squidf> 6.5-2.mga9
+ Revision: 1931104
- Mass rebuild for icu 72.1

* Wed Jun 22 2022 tv <tv> 6.5-1.mga9
+ Revision: 1865415
- 6.5

* Sat Jun 18 2022 squidf <squidf> 6.4-5.mga9
+ Revision: 1864840
- rebuild for icu 71.1

* Thu May 19 2022 pterjan <pterjan> 6.4-4.mga9
+ Revision: 1858887
- Rebuild for OCaml 4.14

* Sat Apr 02 2022 umeabot <umeabot> 6.4-3.mga9
+ Revision: 1840579
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 6.4-2.mga9
+ Revision: 1774973
- rebuild for python-3.10

* Wed Oct 13 2021 tv <tv> 6.4-1.mga9
+ Revision: 1751173
- BR doxygen in order to generate docs
- 6.4

* Tue Oct 12 2021 tv <tv> 6.3-5.mga9
+ Revision: 1750775
- Rebuild for ocaml 4.13.1

* Wed Aug 04 2021 luigiwalser <luigiwalser> 6.3-4.mga9
+ Revision: 1739333
- rebuild for icu

* Thu Mar 18 2021 neoclust <neoclust> 6.3-3.mga9
+ Revision: 1704314
- Rebuild against python 3.9

* Wed Mar 03 2021 neoclust <neoclust> 6.3-2.mga9
+ Revision: 1697191
- Rebuild against ocaml

* Sun Feb 28 2021 tv <tv> 6.3-1.mga9
+ Revision: 1693331
- 6.3

* Sat Dec 05 2020 tv <tv> 6.1-5.mga8
+ Revision: 1653101
- Rebuild for new libicu

* Tue Sep 29 2020 tv <tv> 6.1-4.mga8
+ Revision: 1631102
- use %%find_lang
- BR systemd
- Add systemd unit file (rhbz#916628)
- fix java deps

* Fri Aug 21 2020 pterjan <pterjan> 6.1-3.mga8
+ Revision: 1617693
- Fix version in -dracut dependency on the main package
+ umeabot <umeabot>
- Rebuild for new ocaml deps generator
+ tv <tv>
- add dracut module in its own subpkg

* Fri Apr 10 2020 tv <tv> 6.1-1.mga8
+ Revision: 1566151
- 6.1 (api: 0.6 -> 0.8)
- adjust license
- add support for eSpeak
- better way to pass our flags
- simplify binding descriptions

* Thu Feb 27 2020 umeabot <umeabot> 5.5-11.mga8
+ Revision: 1551117
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 5.5-10.mga8
+ Revision: 1544307
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 tv <tv> 5.5-9.mga8
+ Revision: 1482774
- fix ambiguous python shebang
- rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 09 2019 wally <wally> 5.5-8.mga8
+ Revision: 1438953
- rebuild for python3.8

* Mon Jan 07 2019 shlomif <shlomif> 5.5-7.mga7
+ Revision: 1351495
- Rebuild for python3 3.7

* Thu Oct 25 2018 daviddavid <daviddavid> 5.5-6.mga7
+ Revision: 1325232
- rebuild for new ocaml 4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 5.5-5.mga7
+ Revision: 1323710
- Rebuild for ocaml 4.07

* Sat Sep 22 2018 daviddavid <daviddavid> 5.5-4.mga7
+ Revision: 1295837
- add patch to fix build with new glibc
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 wally <wally> 5.5-3.mga7
+ Revision: 1237877
- fix build on aarch64

* Sun Nov 26 2017 tv <tv> 5.5-2.mga7
+ Revision: 1179443
- rebuild for new ocaml

* Sat Sep 02 2017 guillomovitch <guillomovitch> 5.5-1.mga7
+ Revision: 1150677
- new version 5.5

* Sat Aug 05 2017 pterjan <pterjan> 5.3.1-4.mga7
+ Revision: 1135190
- Rebuild for python 3.6

* Sun Sep 25 2016 pterjan <pterjan> 5.3.1-3.mga6
+ Revision: 1056200
- Rebuild for fix in ocaml

* Thu Apr 28 2016 tv <tv> 5.3.1-2.mga6
+ Revision: 1007133
+ rebuild (emptylog)

* Fri Apr 15 2016 shlomif <shlomif> 5.3.1-1.mga6
+ Revision: 1002674
- New version 5.3.1

* Wed Feb 03 2016 pterjan <pterjan> 4.5-19.mga6
+ Revision: 934176
- Rebuild for new ocaml

* Sun Nov 01 2015 tv <tv> 4.5-18.mga6
+ Revision: 896992
- parallel build seems broken, thus disabling it

* Wed Oct 07 2015 ovitters <ovitters> 4.5-17.mga6
+ Revision: 887036
- rebuild for new python3

* Fri Oct 31 2014 pterjan <pterjan> 4.5-16.mga5
+ Revision: 794863
- Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 4.5-15.mga5
+ Revision: 744038
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.5-14.mga5
+ Revision: 725985
- rebuild for missing pythoneggs deps

* Thu Sep 18 2014 umeabot <umeabot> 4.5-13.mga5
+ Revision: 693516
- Rebuild to fix library dependencies
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 4.5-11.mga5
+ Revision: 629667
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 4.5-10.mga5
+ Revision: 629528
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 4.5-9.mga4
+ Revision: 541432
- Mageia 4 Mass Rebuild
+ pterjan <pterjan>
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 12 2013 solbu <solbu> 4.5-7.mga4
+ Revision: 495898
- Fix BuildRequires
- Rebuild for ncurses/tinfo split
- Rebuild for ncurses/tinfo split

* Sun Jun 30 2013 fwang <fwang> 4.5-5.mga4
+ Revision: 448533
- only build python3 flavour

* Sun Jun 30 2013 fwang <fwang> 4.5-4.mga4
+ Revision: 448525
- import sysconfig
- fix python linking
- update py3dir
- do not use build dir
- add python3 flavour

* Sat Jun 08 2013 fwang <fwang> 4.5-3.mga4
+ Revision: 440443
- we are now link /lib to /usr/lib

* Fri May 31 2013 solbu <solbu> 4.5-2.mga4
+ Revision: 433647
- Fix BuildRequires
- Drop P2, unneeded with correct BuildRequires

* Thu May 30 2013 pterjan <pterjan> 4.5-1.mga4
+ Revision: 433490
- Fix build of python binding
- Use apply_patches
- Update major
+ solbu <solbu>
- New version

* Sat Mar 09 2013 rtp <rtp> 4.4-3.mga3
+ Revision: 401984
- fix build without ocaml opt
- Disable java on arm/mips.

* Fri Jan 11 2013 umeabot <umeabot> 4.4-2.mga3
+ Revision: 347195
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 30 2012 malo <malo> 4.4-1.mga3
+ Revision: 301055
- new version 4.4
- add patch from mdv (pok) to fix java build
- add autoconf to prep (mdv)
- update RPM groups
+ fwang <fwang>
- new version 4.4

* Tue Jun 05 2012 solbu <solbu> 4.3-1.mga3
+ Revision: 255999
- brltty doesn't support concurent builds
- Fix build error
- Spec cleanup
- New version
- Drop patches 5 and 7. merged upstream or not needed.

* Sun Dec 04 2011 malo <malo> 4.2-5.mga2
+ Revision: 176172
- adding missing Requires brlapi-devel for ocaml-brlapi

* Sat Dec 03 2011 malo <malo> 4.2-4.mga2
+ Revision: 175569
- spec cleanup
- renamed brlapi-ocaml to ocaml-brlapi, per policy
- included missing files for the ocaml api
+ fwang <fwang>
- cleanup br

* Sat May 07 2011 tv <tv> 4.2-2.mga1
+ Revision: 95829
- readd back silently deleted "useless macro definition" that
  broke brltty

* Thu May 05 2011 misc <misc> 4.2-1.mga1
+ Revision: 95051
- fix previous patch
- fix build, missing include
- update to 4.2
- remove patch0, uneeded ( or so do I think )
- rediff patch5, ( // make )

* Tue Feb 22 2011 ahmad <ahmad> 4.1-6.mga1
+ Revision: 55873
- rebuild to make all pythonegg requires/provides lowercase
- rebuild against festival without esound support

* Tue Jan 25 2011 misc <misc> 4.1-5.mga1
+ Revision: 38154
- add comments
- remove old %%post
- imported package brltty


* Thu Nov 04 2010 Götz Waschk <waschk@mandriva.org> 4.1-5mdv2011.0
+ Revision: 593321
- rebuild for new python 2.7

  + Funda Wang <fwang@mandriva.org>
    - rebuild for py2.7

* Wed Feb 03 2010 Guillaume Rousse <guillomovitch@mandriva.org> 4.1-2mdv2011.0
+ Revision: 500156
- rebuild for latest ocaml

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 4.1-1mdv2010.1
+ Revision: 462442
- Sync with Fedora:
  * Use configure option to disable stripping instead of patch
  * Use CPPFLAGS variable to fix detection of java includes
  * Use single quotes when passing the value of brltty_summary_lines,
    so that is not garbled.
  * fix parallell make
- BuildRequires: subversion because configure script uses svnversion
- BuildRequires: ncursesw-devel for UTF-8 support
- Update to new version 4.1
- Remove javainclude patch: not needed
- Fix license

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 4.0-3mdv2010.0
+ Revision: 448824
- add buildconflict for findlib, since support for building with
  ocamlfind is broken (from Arnaud Patard)
- disable java on mips & arm (from Arnaud Patard)

* Sun Jul 26 2009 Guillaume Rousse <guillomovitch@mandriva.org> 4.0-2mdv2010.0
+ Revision: 400302
- fix ocaml package description
- fix ocaml files installation

* Sat May 16 2009 Frederik Himpe <fhimpe@mandriva.org> 4.0-1mdv2010.0
+ Revision: 376478
- Re-add java include patch, it is still needed
- Update to new version 4.0
- Remove two build fix patches which ware not needed anymore

* Sat Mar 28 2009 Funda Wang <fwang@mandriva.org> 3.10-2mdv2009.1
+ Revision: 361863
- rebuild for new libxaw

* Fri Dec 26 2008 Adam Williamson <awilliamson@mandriva.org> 3.10-1mdv2009.1
+ Revision: 319142
- guh.
- seriously, what the hell is up with this ocaml crap?
- add package for ocaml bindings
- use proper python macros
- bindings package names should not be libified because they are not shared
  libraries with proper majors: call them brlapi-foo and obsolete the incorrect
  names
- apparently there's no install-help any more
- rebuild with python 2.6
- new release 3.10
- rediff javainclude.patch
- drop declarator.patch (merged upstream)

* Fri Jul 04 2008 Oden Eriksson <oeriksson@mandriva.com> 3.9-7mdv2009.0
+ Revision: 231824
- rebuild

  + Adam Williamson <awilliamson@mandriva.org>
    - better approach to java buildrequires and path suggested by anssi

* Fri Jul 04 2008 Adam Williamson <awilliamson@mandriva.org> 3.9-5mdv2009.0
+ Revision: 231509
- have python package obsolete its old name

* Fri Jul 04 2008 Adam Williamson <awilliamson@mandriva.org> 3.9-4mdv2009.0
+ Revision: 231484
- don't package COPYING
- explicitly specify JAVA_HOME to fix java bindings build
- have actually-useful explicit provides for python and java packages
- enable java bindings build on all arches
- add javainclude.patch to fix java include paths for openjdk
- add declarator.patch to fix "empty declarator" build error (from upstream SVN)
- add buildworkaround.patch to fix a known but yet unresolved build error
  (this workaround provided by upstream in mailing list)
- rediff and reapply varargs.patch and dontstrip.patch (silently disabled by
  aginies in 3.9-1mdv)
- new license policy
- proper library / devel naming policy, not the hideous mess previously used
- slight clean and re-arrange of spec

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Antoine Ginies <aginies@mandriva.com>
    - remove commented line %%configure due to strange build error on BS...
    - remove redundant install in %%install
    - update buildrequires
    - bump release
    - add some buildrequires, restore java-bindings for 32b

* Mon Mar 10 2008 Antoine Ginies <aginies@mandriva.com> 3.9-1mdv2008.1
+ Revision: 183865
- disable some bindings for the moment
- include new bindings, 3.9 version, major update
- 3.9 version

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - fix spacing at top of description
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Jun 04 2007 Frederic Crozat <fcrozat@mandriva.com> 3.7.2-6mdv2008.0
+ Revision: 35101
- Patch1 (Fedora): don't strip binaries, otherwise debug packages are empty
- Import brltty



* Sat Aug 12 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.7.2-5
- rebuild for fixed libxaw soname

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 3.7.2-4mdv2007.0
- generate api library subpackage

* Fri Apr 28 2006 Pixel <pixel@mandriva.com> 3.7.2-3mdk
- rebuild (so that the strange require on libbrlapi.so.0.4 disappear...)

* Tue Mar 28 2006 Pascal Terjan <pterjan@mandriva.org> 3.7.2-2mdk
- BuildRequires X11-devel
- Have /bin/brltty-config executable
- Would need some more fixes (rpath to '../../Programs', use of /lib)

* Fri Mar 24 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 3.7.2-1mdk
- 3.7.2
- fix permission on conf file
- regenerate P0
- drop P1 (fixed upstream)
- fix summary-ended-with-dot
- %%mkrel

* Wed Aug 31 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.6-2mdk
- gcc4 fixes

* Mon Nov 15 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.6-1mdk
- 3.6
- regenerate P0

* Tue Sep 14 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 3.5-2mdk
- varargs fixes

* Fri Jun 18 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-1mdk
- 3.5 final

* Fri Apr 16 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-0.pre3.1mdk
- 3.5pre3

* Fri Apr 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-0.pre2.1mdk
- 3.5pre2
- enable parallell build again:)

* Thu Jan 22 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.4.1-1mdk
- 3.4.1

* Thu Nov 20 2003 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.3.1-1mdk
- 3.3.1
- disable parallell build, broken:\
- merge with debian patches (P0)

* Sun May 11 2003 Stefan van der Eijk <stefan@eijk.nu> 3.2-0.2mdk
- BuildRequires

* Tue Feb  4 2003 Pixel <pixel@mandrakesoft.com> 3.2-0.1mdk
- new beta
- cleanup

* Sat Feb 01 2003 Lenny Cartier <lenny@mandrakesoft.com 3.1-5mdk
- rebuild

* Mon Nov 04 2002 Lenny Cartier <lenny@mandrakesoft.com> 3.1-4mdk
- from Per Øyvind Karlsen <peroyvind@delonic.no> :
	- Whoopsy! Libraries did'nt go to /lib, fixed

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-3mdk
- Added more doc's
- Updated to final(?) 3.1 version

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-2mdk
- Added more doc's
- Move stuff into /bin and /lib since we want brltty can be used when only
  the root file system is mounted
- Cleanups

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-1mdk
- Initial release
